==> volpy-0.1.2.dev0-py3-none-any.whl: volpy/__init__.py <==
import sys
sys.path.append('volpy/')  # because we are calling the package from root
from coordinates import CoordinateSystem
from survey import Survey as load_survey
from geometry import TriangularMesh as terrain_mesh
from plots import SurveyPlot as terrain_plots

def demo():
    """
    A quick demo of this package. It loads a dataset available internally,
    displays information about it and related graphs: 3D Scatter, Contour,
    Histogram and 2D Scatter and finally the Volume Curves.
    """
    print("Loading sample survey data...")
    survey = load_survey('volpy/sample_data/survey_ibema_faxinal_Cartesian.csv',
        'Ibema Faxinal')
    if survey is not None:
        print('Sample survey data loaded successfully.')
        print("---")
        print("Sample survey information:")
        print("Maximum elevation: {:.2f} meters.".format(
            survey.data['elevation'].max()))
        print("Elevation delta: {:.2f} meters.".format(
            survey.data['elevation'].max() - survey.data['elevation'].min()))
        print("Survey data count: {} points.".format(
            survey.data['elevation'].count()))
        print("---")
        print("Generating survey plots...")
        plots = terrain_plots(survey)
        plots.scatter3d()
        plots.contour()
        plots.profile()
        plots.mesh_plot()
        print('---')
        print('Calculating total terrain volume...')
        mesh = terrain_mesh(survey.data)
        volume = mesh.get_volume()
        print("Total volume: {:.2f} cubic meters".format(volume))
    else:
        print('Error while loading sample survey data.')

==> volpy-0.1.6.dev0-py3-none-any.whl: volpy/__init__.py <==
from .coordinates import CoordinateSystem
from .survey import Survey as load_survey
from .geometry import TriangularMesh as terrain_mesh
from .plots import SurveyPlot as terrain_plots

def demo():
    """
    A quick demo of this package. It loads a dataset available internally,
    displays information about it and related graphs: 3D Scatter, Contour,
    Histogram and 2D Scatter and finally the Volume Curves.
    """
    print("Loading sample survey data...")
    survey = load_survey('sample_data/survey_ibema_faxinal_Cartesian.csv',
        'Ibema Faxinal')
    if survey is not None:
        print('Sample survey data loaded successfully.')
        print("---")
        print("Sample survey information:")
        print("Maximum elevation: {:.2f} meters.".format(
            survey.data['elevation'].max()))
        print("Elevation delta: {:.2f} meters.".format(
            survey.data['elevation'].max() - survey.data['elevation'].min()))
        print("Survey data count: {} points.".format(
            survey.data['elevation'].count()))
        print("---")
        print("Generating survey plots...")
        plots = terrain_plots(survey)
        plots.scatter3d()
        plots.contour()
        plots.profile()
        plots.mesh_plot()
        print('---')
        print('Calculating total terrain volume...')
        mesh = terrain_mesh(survey.data)
        volume = mesh.get_volume()
        print("Total volume: {:.2f} cubic meters".format(volume))
    else:
        print('Error while loading sample survey data.')
